%define ALD_Ver		1.2.1

Name:         ghostscript

License:      GPL
Summary:      Ghostscript
Group:        Applications/Publishing
Version:      8.71
Release:      1
Url: http://www.ghostscript.com/

Requires:	libpng
Requires:	libjpeg
Requires:	tiff >= 3.9.6
Requires:	libpaper

Source: %{name}-%{version}.tar.xz
Patch0: ghostscript-8.71.patch
Source1: CROSS.sh

%define DestDir		/ps_pdf_printer
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_sysconfdir %{csysdir}%{_sysconfdir}
%define cross_bindir	%{csysdir}%{_bindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%define Build_gcc CCAUX="gcc -O2"
%define cX11_libdir	%{csysdir}%{_prefix}/X11/%{_lib}
%define cX11_includedir	%{csysdir}%{_prefix}/X11/include

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}
%define Build_gcc %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}


%define gsMakeFlags SHARE_JPEG=1 SHARE_LIBPNG=1 SHARE_LIBTIFF=1 SHARE_ZLIB=1 SHARE_EXPAT=1

# ------------------- description ------------------------------------
%description
gs - Ghostscript (PostScript and PDF language interpreter and previewer)
#-------------------------------
%package gsx
Summary:      gsx
Group:        Applications/Publishing
%description gsx
gsx
#-------------------------------
%package Fonts
Summary:      Fonts for ghostscript
Group:        Applications/Publishing
%description Fonts
Fonts for ghostscript 
#-------------------------------
%package CMap
Summary:      CMap for ghostscript
Group:        Applications/Publishing
%description CMap
CMap for ghostscript 
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package printer
Summary:      printers lib
Group:        Applications/Publishing
%description printer
printers lib
#-------------------------------
%package perl
Summary:      perl script fixmswrd.pl
Group:        Applications/Publishing
%description perl
This program patches the postscript generated by MS Word printer drivers
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
%patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fPIC -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
%if %{_target_cpu} == "armv7l"
OPTFLAGS="-O2 -fPIC -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%else
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif
%endif

%if %{_os} == "mingw"
CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS=" "
%else
CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=`case $GCC_VER_STR in \
 4.[56789].*) echo -static-libgcc ;; \
 esac`
LDFLAGS="$LDFLAGS -Wl,--gc-sections"
%endif

fontpath="%{_datadir}/fonts/default/ghostscript"
fontpath="${fontpath}:%{_datadir}/fonts/default/Type1"
fontpath="${fontpath}:%{_datadir}/fonts/default/TrueType"
fontpath="${fontpath}:/usr/X11/lib/X11/fonts/Type1"
fontpath="${fontpath}:/usr/X11/lib/X11/fonts/TrueType"
fontpath="${fontpath}:/usr/X11/lib/X11/fonts/75dpi"
fontpath="${fontpath}:/usr/X11/lib/X11/fonts/misc"
fontpath="${fontpath}:/usr/X11/lib/X11/fonts/100dpi"
%if 1
fontpath="${fontpath}:/usr/share/cups/fonts"
%else
if test -f /usr/bin/cups-config; then
  fontpath="${fontpath}:`/usr/bin/cups-config --datadir`/fonts"
fi
%endif

export PKG_CONFIG_PATH=" "

%if %{_CROSS}
export ac_cv_have_x="have_x=yes ac_x_includes=%{cX11_includedir} ac_x_libraries=%{cX11_libdir}"
export ac_cv_path_PKGCONFIG="%{target}-pkg-config"
export ac_cv_func_malloc_0_nonnull="yes"
export ac_cv_func_memcmp_working="yes"
export ac_cv_func_stat_empty_string_bug="no"
%endif


%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-debug \
	--disable-gtk \
	--disable-cairo \
	--enable-dynamic \
	--with-drivers=BMP,FAX,JPEG,PNG,PS,TIFF \
	--with-fontpath=$fontpath \
	--disable-compile-inits \
	--without-ijs \
	--without-jbig2dec \
	--without-jasper \
	--without-omni \
	--with-x \
	&>FConfigure_log.txt 

#	--with-drivers=BMP,FAX,JPEG,PNG,PS,TIFF,CAIRO,BROTHER,EPSON,HP,IBM,LEXMARK,OKI,PCLXL 

make  %{Build_gcc} %{gsMakeFlags} so &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT %{Build_gcc} %{gsMakeFlags} soinstall install-cups &>FInstall_so_log.txt

cp LICENSE doc/AUTHORS doc/COPYING $RPM_BUILD_ROOT%{docdir}/

pushd $RPM_BUILD_ROOT%{_bindir}
mv gsc gs
popd

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{cross_sysconfdir}
rm -r $RPM_BUILD_ROOT%{cross_bindir}
rm -r $RPM_BUILD_ROOT%{cross_libdir}/cups
rm -r $RPM_BUILD_ROOT%{cross_datadir}/cups
rm -r $RPM_BUILD_ROOT%{cross_datadir}/ghostscript
rm -r $RPM_BUILD_ROOT%{cross_mandir}
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
%if (%{_os} == "mingw")
  rm %{name}-$SE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%else  #mingw
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-gsx-$SE $DD/%{name}-gsx-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
  mv %{name}-CMap-$SE $DD/%{name}-CMap-$DE
  mv %{name}-printer-$SE $DD/%{name}-printer-$DE
  mv %{name}-Fonts-$SE $DD/%{name}-Fonts-$DE
  mv %{name}-perl-$SE $DD/%{name}-perl-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
%endif #!mingw
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
%if (%{_os} == "mingw")
  TMP_TO=$DD
%else
  TMP_TO=$DD/tar
%endif
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r etc usr $tmp/
%if (%{_os} == "mingw")
  zip -9 -r $tmp.zip $tmp >/dev/null
  mv $tmp.zip $TMP_TO
%else
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
%endif
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%if %{_os} == "mingw"
%Files
%{_prefix}

%if %{BUILD_LOCAL_CROSS}
%Files %{TO_ARCH}
%{csysdir}
%endif #!BUILD_LOCAL_CROSS
%else  #mingw

%Files
/etc/cups
%exclude %{_bindir}/fixmswrd.pl
%exclude %{_bindir}/gsx
%{_bindir}
%{_libdir}/*.so.*
%{_libdir}/cups
%{_datadir}/cups
%{_datadir}/ghostscript/%{version}/Resource/ColorSpace
%{_datadir}/ghostscript/%{version}/Resource/Decoding
%{_datadir}/ghostscript/%{version}/Resource/Encoding
%{_datadir}/ghostscript/%{version}/Resource/Font/Nimbus*
%{_datadir}/ghostscript/%{version}/Resource/Font/StandardSymL
%{_datadir}/ghostscript/%{version}/Resource/Init
%{_datadir}/ghostscript/%{version}/Resource/SubstCID
%{_datadir}/ghostscript/%{version}/lib/PDFA_def.ps
%{_datadir}/ghostscript/%{version}/lib/PDFX_def.ps
%{_datadir}/ghostscript/%{version}/lib/a*
%{_datadir}/ghostscript/%{version}/lib/bdftops.ps
%{_datadir}/ghostscript/%{version}/lib/caption.ps
%{_datadir}/ghostscript/%{version}/lib/cid2code.ps
%{_datadir}/ghostscript/%{version}/lib/decrypt.ps
%{_datadir}/ghostscript/%{version}/lib/dmp*
%{_datadir}/ghostscript/%{version}/lib/docie.ps
%{_datadir}/ghostscript/%{version}/lib/dumphint.ps
%{_datadir}/ghostscript/%{version}/lib/escp_24.src
%{_datadir}/ghostscript/%{version}/lib/font2*
%{_datadir}/ghostscript/%{version}/lib/ghostpdf.ppd
%{_datadir}/ghostscript/%{version}/lib/gs*
%{_datadir}/ghostscript/%{version}/lib/ht_ccsto.ps
%{_datadir}/ghostscript/%{version}/lib/i*
%{_datadir}/ghostscript/%{version}/lib/j*
%{_datadir}/ghostscript/%{version}/lib/l*
%{_datadir}/ghostscript/%{version}/lib/m*
%{_datadir}/ghostscript/%{version}/lib/p*
%{_datadir}/ghostscript/%{version}/lib/quit.ps
%{_datadir}/ghostscript/%{version}/lib/r*
%{_datadir}/ghostscript/%{version}/lib/show*
%{_datadir}/ghostscript/%{version}/lib/stcinfo.ps
%{_datadir}/ghostscript/%{version}/lib/stcolor.ps
%{_datadir}/ghostscript/%{version}/lib/stocht.ps
%{_datadir}/ghostscript/%{version}/lib/t*
%{_datadir}/ghostscript/%{version}/lib/u*
%{_datadir}/ghostscript/%{version}/lib/v*
%{_datadir}/ghostscript/%{version}/lib/w*
%{_datadir}/ghostscript/%{version}/lib/z*
%{_mandir}
%{docdir}

%files gsx
%{_bindir}/gsx
%{_libdir}/ghostscript/%{version}/X11.so

%files Fonts
%{_datadir}/ghostscript/%{version}/Resource/Font/Century*
%{_datadir}/ghostscript/%{version}/Resource/Font/Dingbats
%{_datadir}/ghostscript/%{version}/Resource/Font/URW*

%files CMap
%{_datadir}/ghostscript/%{version}/Resource/CMap

%files printer
%{_datadir}/ghostscript/%{version}/lib/PM*
%{_datadir}/ghostscript/%{version}/lib/St*
%{_datadir}/ghostscript/%{version}/lib/bj*
%{_datadir}/ghostscript/%{version}/lib/cb*
%{_datadir}/ghostscript/%{version}/lib/cd*
%{_datadir}/ghostscript/%{version}/lib/dnj*
%{_datadir}/ghostscript/%{version}/lib/n*
%{_datadir}/ghostscript/%{version}/lib/s400*
%{_datadir}/ghostscript/%{version}/lib/sharp.upp
%{_datadir}/ghostscript/%{version}/lib/sipixa6.upp
%{_datadir}/ghostscript/%{version}/lib/st640*
%{_datadir}/ghostscript/%{version}/lib/stc.upp
%{_datadir}/ghostscript/%{version}/lib/stc1520h.upp
%{_datadir}/ghostscript/%{version}/lib/stc2*
%{_datadir}/ghostscript/%{version}/lib/stc3*
%{_datadir}/ghostscript/%{version}/lib/stc5*
%{_datadir}/ghostscript/%{version}/lib/stc6*
%{_datadir}/ghostscript/%{version}/lib/stc7*
%{_datadir}/ghostscript/%{version}/lib/stc8*
%{_datadir}/ghostscript/%{version}/lib/stc_*
%{_datadir}/ghostscript/%{version}/lib/stcany*

%files doc
%{_datadir}/ghostscript/%{version}/doc
%{_datadir}/ghostscript/%{version}/examples

%files perl
%{_bindir}/fixmswrd.pl

%files devel
%{_libdir}/*.so
%{_includedir}

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{cross_libdir}
%{cross_includedir}
%{cross_docdir}

%endif #!BUILD_LOCAL_CROSS
%endif #!mingw
